@@ -1,5 +1,6 @@
 from tiny_blocks.load.to_csv import ToCSV, KwargsToCSV
 from tiny_blocks.load.to_sql import ToSQL, KwargsToSQL
+from tiny_blocks.load.to_kafka import ToKafka, KwargsToKafka
 
 
 __all__ = [
@@ -7,4 +8,6 @@ __all__ = [
     "KwargsToCSV",
     "ToSQL",
     "KwargsToSQL",
+    "ToKafka",
+    "KwargsToKafka",
 ]
