@@ -9,6 +9,8 @@ from tiny_blocks.transform.merge import Merge, KwargsMerge
 from tiny_blocks.transform.rename import Rename, KwargsRename
 from tiny_blocks.transform.sort import Sort, KwargsSort
 from tiny_blocks.transform.apply import Apply, KwargsApply
+from tiny_blocks.transform.drop_columns import DropColumns, KwargsDropColumns
+from tiny_blocks.transform.validate import Validate
 
 __all__ = [
     "Apply",
@@ -27,4 +29,7 @@ __all__ = [
     "KwargsRename",
     "Sort",
     "KwargsSort",
+    "DropColumns",
+    "KwargsDropColumns",
+    "Validate",
 ]
