@@ -23,14 +23,16 @@ class Astype(TransformBase):
     """
     Astype Block. Defines the type casting for column dataframes.
 
-    Basic Usage:
+    Basic example:
         >>> import pandas as pd
         >>> from tiny_blocks.transform import Astype
         >>> from tiny_blocks.extract import FromCSV
+        >>>
         >>> from_csv = FromCSV(path="/path/to/file.csv")
         >>> as_type = Astype(dtype={"e": "float32"})
-        >>> source = from_csv.get_iter()
-        >>> generator = as_type.get_iter(source)
+        >>>
+        >>> generator = from_csv.get_iter()
+        >>> generator = as_type.get_iter(generator)
         >>> df = pd.concat(generator)
 
     For more Kwargs info:
